#!/usr/bin/env python3
"""Backwards-compatible setup.py for pip install.

This file is provided for compatibility with older pip versions.
The main configuration is in pyproject.toml.
"""
from setuptools import setup

if __name__ == "__main__":
    setup()
